==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QAbstractFileIconProvider_shell.h <==
#ifndef QABSTRACTFILEICONPROVIDER_SHELL_H
#define QABSTRACTFILEICONPROVIDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtGui/qabstractfileiconprovider.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qfileinfo.h>
#include <QtGui/qicon.h>
#include <QtJambi/RegistryAPI>


class QAbstractFileIconProvider_shell : public QAbstractFileIconProvider, public QtJambiShellInterface
{
public:
    QAbstractFileIconProvider_shell();
    ~QAbstractFileIconProvider_shell() override;

    QIcon icon(QAbstractFileIconProvider::IconType arg__1) const override;
    QIcon icon(const QFileInfo& arg__1) const override;
    QAbstractFileIconProvider::Options options() const override;
    void setOptions(QAbstractFileIconProvider::Options arg__1) override;
    QString type(const QFileInfo& arg__1) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractFileIconProvider_access : public QAbstractFileIconProvider
{
    jobject __qt_icon_QAbstractFileIconProvider_IconType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jobject __qt_icon_cref_QFileInfo_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jint __qt_options(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setOptions_QAbstractFileIconProvider_Options(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1);
    jstring __qt_type_cref_QFileInfo_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
};

#endif // QABSTRACTFILEICONPROVIDER_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QAbstractFileIconProvider_shell.h <==
#ifndef QABSTRACTFILEICONPROVIDER_SHELL_H
#define QABSTRACTFILEICONPROVIDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtGui/qabstractfileiconprovider.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qfileinfo.h>
#include <QtGui/qicon.h>
#include <QtJambi/RegistryAPI>


class QAbstractFileIconProvider_shell : public QAbstractFileIconProvider, public QtJambiShellInterface
{
public:
    QAbstractFileIconProvider_shell();
    ~QAbstractFileIconProvider_shell() override;

    QIcon icon(QAbstractFileIconProvider::IconType arg__1) const override;
    QIcon icon(const QFileInfo& arg__1) const override;
    QAbstractFileIconProvider::Options options() const override;
    void setOptions(QAbstractFileIconProvider::Options arg__1) override;
    QString type(const QFileInfo& arg__1) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractFileIconProvider_access : public QAbstractFileIconProvider
{
    jobject __qt_icon_QAbstractFileIconProvider_IconType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jobject __qt_icon_cref_QFileInfo_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jint __qt_options_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setOptions_QAbstractFileIconProvider_Options(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1);
    jstring __qt_type_cref_QFileInfo_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
};

#endif // QABSTRACTFILEICONPROVIDER_SHELL_H
